@@ -16,7 +16,10 @@ class TestRequests(unittest.TestCase):
         self.assertEqual(res.status_code, 200)
 
     def test_invalid_request_error(self):
-        self.assertRaises(Exception, post, 'testsecret', '[{]')
+        self.assertRaises(Exception, post, 'testsecret', 'https://api.segment.io', '[{]')
+
+    def test_invalid_host(self):
+        self.assertRaises(Exception, post, 'testsecret', 'api.segment.io/', batch=[])
 
     def test_datetime_serialization(self):
         data = { 'created': datetime(2012, 3, 4, 5, 6, 7, 891011) }
